==> bootstrap-core-1.0.92-sources.jar: com/turbospaces/boot/GlobalPlatformScheduledExecutorService.java <==
package com.turbospaces.boot;

import java.time.Duration;
import java.util.Collection;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.Future;
import java.util.concurrent.ScheduledFuture;
import java.util.concurrent.ScheduledThreadPoolExecutor;
import java.util.concurrent.ThreadPoolExecutor.CallerRunsPolicy;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;

import org.apache.commons.lang3.time.StopWatch;

import com.google.common.util.concurrent.ListenableFuture;
import com.google.common.util.concurrent.ListenableScheduledFuture;
import com.google.common.util.concurrent.ListeningScheduledExecutorService;
import com.google.common.util.concurrent.MoreExecutors;
import com.google.common.util.concurrent.ThreadFactoryBuilder;
import com.turbospaces.common.PlatformUtil;

import io.micrometer.core.instrument.binder.jvm.ExecutorServiceMetrics;
import io.vavr.CheckedRunnable;
import lombok.extern.slf4j.Slf4j;

@Slf4j
public class GlobalPlatformScheduledExecutorService extends AbstractBootstrapAware implements PlatformScheduledExecutorService {
    private ListeningScheduledExecutorService executor;

    @Override
    public void afterPropertiesSet() {
        int size = bootstrap.props().APP_PLATFORM_POOL_SIZE.get();

        ThreadFactoryBuilder factory = new ThreadFactoryBuilder();
        factory.setDaemon(false);
        factory.setNameFormat("global-worker-%d");

        ScheduledThreadPoolExecutor pool = new ScheduledThreadPoolExecutor(size, factory.build(), new CallerRunsPolicy());
        pool.prestartAllCoreThreads();
        executor = MoreExecutors.listeningDecorator(pool);

        ExecutorServiceMetrics metrics = new ExecutorServiceMetrics(pool, "platform", Collections.emptyList());
        metrics.bindTo(bootstrap.meterRegistry());
    }
    @Override
    public void destroy() {
        StopWatch stopWatch = StopWatch.createStarted();
        Duration timeout = bootstrap.props().APP_PLATFORM_GRACEFUL_SHUTDOWN_TIMEOUT.get();
        PlatformUtil.shutdownExecutor(executor, timeout);
        stopWatch.stop();

        logger.debug("stopped global scheduled-executor-service: {} in {}", executor, stopWatch);
    }
    @Override
    public ListenableFuture<?> execute(CheckedRunnable action) {
        return submit(new Runnable() {
            @Override
            public void run() {
                try {
                    action.run();
                } catch (Throwable err) {
                    log.error(err.getMessage(), err);
                }
            }
        });
    }
    @Override
    public void execute(Runnable command) {
        Map<String, String> mdcContextMap = getMdcContextMap();
        executor.execute(wrapRunnable(command, mdcContextMap));
    }
    @Override
    public ListenableFuture<?> submit(Runnable task) {
        Map<String, String> mdcContextMap = getMdcContextMap();
        return executor.submit(wrapRunnable(task, mdcContextMap));
    }
    @Override
    public <T> ListenableFuture<T> submit(Callable<T> task) {
        Map<String, String> mdcContextMap = getMdcContextMap();
        return executor.submit(wrapCallable(task, mdcContextMap));
    }
    @Override
    public <T> ListenableFuture<T> submit(Runnable task, T result) {
        Map<String, String> mdcContextMap = getMdcContextMap();
        return executor.submit(wrapRunnable(task, mdcContextMap), result);
    }
    @Override
    public ListenableScheduledFuture<?> schedule(Runnable command, long delay, TimeUnit unit) {
        Map<String, String> mdcContextMap = getMdcContextMap();
        return executor.schedule(wrapRunnable(command, mdcContextMap), delay, unit);
    }
    public ListenableScheduledFuture<?> schedule(Runnable command, Duration delay) {
        Map<String, String> mdcContextMap = getMdcContextMap();
        return executor.schedule(wrapRunnable(command, mdcContextMap), delay);
    }
    public <V> ListenableScheduledFuture<V> schedule(Callable<V> callable, Duration delay) {
        Map<String, String> mdcContextMap = getMdcContextMap();
        return executor.schedule(wrapCallable(callable, mdcContextMap), delay);
    }
    @Override
    public <V> ListenableScheduledFuture<V> schedule(Callable<V> callable, long delay, TimeUnit unit) {
        Map<String, String> mdcContextMap = getMdcContextMap();
        return executor.schedule(wrapCallable(callable, mdcContextMap), delay, unit);
    }
    @Override
    public ListenableScheduledFuture<?> scheduleAtFixedRate(Runnable command, long initialDelay, long period, TimeUnit unit) {
        return executor.scheduleAtFixedRate(command, initialDelay, period, unit);
    }
    public ListenableScheduledFuture<?> scheduleWithFixedDelay(Runnable command, Duration initialDelay, Duration delay) {
        return executor.scheduleWithFixedDelay(command, initialDelay, delay);
    }
    @Override
    public ScheduledFuture<?> scheduleWithFixedDelay(Runnable command, long initialDelay, long delay, TimeUnit unit) {
        return executor.scheduleWithFixedDelay(command, initialDelay, delay, unit);
    }
    @Override
    public void shutdown() {
        executor.shutdown();
    }
    @Override
    public List<Runnable> shutdownNow() {
        return executor.shutdownNow();
    }
    @Override
    public boolean isShutdown() {
        return executor.isShutdown();
    }
    @Override
    public boolean isTerminated() {
        return executor.isTerminated();
    }
    @Override
    public boolean awaitTermination(long timeout, TimeUnit unit) throws InterruptedException {
        return executor.awaitTermination(timeout, unit);
    }
    @Override
    public <T> List<Future<T>> invokeAll(Collection<? extends Callable<T>> tasks) throws InterruptedException {
        return executor.invokeAll(tasks);
    }
    @Override
    public <T> List<Future<T>> invokeAll(Collection<? extends Callable<T>> tasks, long timeout, TimeUnit unit) throws InterruptedException {
        return executor.invokeAll(tasks, timeout, unit);
    }
    @Override
    public <T> T invokeAny(Collection<? extends Callable<T>> tasks) throws InterruptedException, ExecutionException {
        return executor.invokeAny(tasks);
    }
    @Override
    public <T> T invokeAny(Collection<? extends Callable<T>> tasks, long timeout, TimeUnit unit) throws InterruptedException, ExecutionException, TimeoutException {
        return executor.invokeAny(tasks, timeout, unit);
    }
}

==> bootstrap-core-1.0.93-sources.jar: com/turbospaces/boot/GlobalPlatformScheduledExecutorService.java <==
package com.turbospaces.boot;

import java.time.Duration;
import java.util.Collection;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.Future;
import java.util.concurrent.ScheduledFuture;
import java.util.concurrent.ScheduledThreadPoolExecutor;
import java.util.concurrent.ThreadPoolExecutor.CallerRunsPolicy;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;

import org.apache.commons.lang3.time.StopWatch;

import com.google.common.util.concurrent.ListenableFuture;
import com.google.common.util.concurrent.ListenableScheduledFuture;
import com.google.common.util.concurrent.ListeningScheduledExecutorService;
import com.google.common.util.concurrent.MoreExecutors;
import com.google.common.util.concurrent.SettableFuture;
import com.google.common.util.concurrent.ThreadFactoryBuilder;
import com.turbospaces.common.PlatformUtil;

import io.micrometer.core.instrument.binder.jvm.ExecutorServiceMetrics;
import io.vavr.CheckedRunnable;

public class GlobalPlatformScheduledExecutorService extends AbstractBootstrapAware implements PlatformScheduledExecutorService {
    private ListeningScheduledExecutorService executor;

    @Override
    public void afterPropertiesSet() {
        int size = bootstrap.props().APP_PLATFORM_POOL_SIZE.get();

        ThreadFactoryBuilder factory = new ThreadFactoryBuilder();
        factory.setDaemon(false);
        factory.setNameFormat("global-worker-%d");

        ScheduledThreadPoolExecutor pool = new ScheduledThreadPoolExecutor(size, factory.build(), new CallerRunsPolicy());
        pool.prestartAllCoreThreads();
        executor = MoreExecutors.listeningDecorator(pool);

        ExecutorServiceMetrics metrics = new ExecutorServiceMetrics(pool, "platform", Collections.emptyList());
        metrics.bindTo(bootstrap.meterRegistry());
    }
    @Override
    public void destroy() {
        StopWatch stopWatch = StopWatch.createStarted();
        Duration timeout = bootstrap.props().APP_PLATFORM_GRACEFUL_SHUTDOWN_TIMEOUT.get();
        PlatformUtil.shutdownExecutor(executor, timeout);
        stopWatch.stop();

        logger.debug("stopped global scheduled-executor-service: {} in {}", executor, stopWatch);
    }
    @Override
    public ListenableFuture<?> execute(CheckedRunnable action) {
        SettableFuture<Object> settable = SettableFuture.create();

        submit(new Runnable() {
            @Override
            public void run() {
                try {
                    action.run();
                    settable.set(new Object());
                } catch (Throwable err) {
                    settable.setException(err);
                }
            }
        });

        return settable;
    }
    @Override
    public void execute(Runnable command) {
        Map<String, String> mdcContextMap = getMdcContextMap();
        executor.execute(wrapRunnable(command, mdcContextMap));
    }
    @Override
    public ListenableFuture<?> submit(Runnable task) {
        Map<String, String> mdcContextMap = getMdcContextMap();
        return executor.submit(wrapRunnable(task, mdcContextMap));
    }
    @Override
    public <T> ListenableFuture<T> submit(Callable<T> task) {
        Map<String, String> mdcContextMap = getMdcContextMap();
        return executor.submit(wrapCallable(task, mdcContextMap));
    }
    @Override
    public <T> ListenableFuture<T> submit(Runnable task, T result) {
        Map<String, String> mdcContextMap = getMdcContextMap();
        return executor.submit(wrapRunnable(task, mdcContextMap), result);
    }
    @Override
    public ListenableScheduledFuture<?> schedule(Runnable command, long delay, TimeUnit unit) {
        Map<String, String> mdcContextMap = getMdcContextMap();
        return executor.schedule(wrapRunnable(command, mdcContextMap), delay, unit);
    }
    public ListenableScheduledFuture<?> schedule(Runnable command, Duration delay) {
        Map<String, String> mdcContextMap = getMdcContextMap();
        return executor.schedule(wrapRunnable(command, mdcContextMap), delay);
    }
    public <V> ListenableScheduledFuture<V> schedule(Callable<V> callable, Duration delay) {
        Map<String, String> mdcContextMap = getMdcContextMap();
        return executor.schedule(wrapCallable(callable, mdcContextMap), delay);
    }
    @Override
    public <V> ListenableScheduledFuture<V> schedule(Callable<V> callable, long delay, TimeUnit unit) {
        Map<String, String> mdcContextMap = getMdcContextMap();
        return executor.schedule(wrapCallable(callable, mdcContextMap), delay, unit);
    }
    @Override
    public ListenableScheduledFuture<?> scheduleAtFixedRate(Runnable command, long initialDelay, long period, TimeUnit unit) {
        return executor.scheduleAtFixedRate(command, initialDelay, period, unit);
    }
    public ListenableScheduledFuture<?> scheduleWithFixedDelay(Runnable command, Duration initialDelay, Duration delay) {
        return executor.scheduleWithFixedDelay(command, initialDelay, delay);
    }
    @Override
    public ScheduledFuture<?> scheduleWithFixedDelay(Runnable command, long initialDelay, long delay, TimeUnit unit) {
        return executor.scheduleWithFixedDelay(command, initialDelay, delay, unit);
    }
    @Override
    public void shutdown() {
        executor.shutdown();
    }
    @Override
    public List<Runnable> shutdownNow() {
        return executor.shutdownNow();
    }
    @Override
    public boolean isShutdown() {
        return executor.isShutdown();
    }
    @Override
    public boolean isTerminated() {
        return executor.isTerminated();
    }
    @Override
    public boolean awaitTermination(long timeout, TimeUnit unit) throws InterruptedException {
        return executor.awaitTermination(timeout, unit);
    }
    @Override
    public <T> List<Future<T>> invokeAll(Collection<? extends Callable<T>> tasks) throws InterruptedException {
        return executor.invokeAll(tasks);
    }
    @Override
    public <T> List<Future<T>> invokeAll(Collection<? extends Callable<T>> tasks, long timeout, TimeUnit unit) throws InterruptedException {
        return executor.invokeAll(tasks, timeout, unit);
    }
    @Override
    public <T> T invokeAny(Collection<? extends Callable<T>> tasks) throws InterruptedException, ExecutionException {
        return executor.invokeAny(tasks);
    }
    @Override
    public <T> T invokeAny(Collection<? extends Callable<T>> tasks, long timeout, TimeUnit unit) throws InterruptedException, ExecutionException, TimeoutException {
        return executor.invokeAny(tasks, timeout, unit);
    }
}
